@@ -1,9 +1,11 @@
-from .core import StructuredNode, db
-from .properties import AliasProperty
-from .exceptions import MultipleNodesReturned
-from .match_q import Q, QBase
 import inspect
 import re
+
+from .core import StructuredNode, db
+from .exceptions import MultipleNodesReturned
+from .match_q import Q, QBase
+from .properties import AliasProperty
+
 OUTGOING, INCOMING, EITHER = 1, -1, 0
 
 
@@ -14,7 +16,15 @@ except NameError:
     basestring = str
 
 
-def _rel_helper(lhs, rhs, ident=None, relation_type=None, direction=None, relation_properties=None, **kwargs):
+def _rel_helper(
+    lhs,
+    rhs,
+    ident=None,
+    relation_type=None,
+    direction=None,
+    relation_properties=None,
+    **kwargs,
+):
     """
     Generate a relationship matching string, with specified parameters.
     Examples:
@@ -36,32 +46,48 @@ def _rel_helper(lhs, rhs, ident=None, relation_type=None, direction=None, relati
     """
 
     if direction == OUTGOING:
-        stmt = '-{0}->'
+        stmt = "-{0}->"
     elif direction == INCOMING:
-        stmt = '<-{0}-'
+        stmt = "<-{0}-"
     else:
-        stmt = '-{0}-'
+        stmt = "-{0}-"
 
-    rel_props = ''
+    rel_props = ""
 
     if relation_properties:
-        rel_props = ' {{{0}}}'.format(', '.join(
-            ['{0}: {1}'.format(key, value) for key, value in relation_properties.items()]))
+        rel_props = " {{{0}}}".format(
+            ", ".join(
+                [
+                    "{0}: {1}".format(key, value)
+                    for key, value in relation_properties.items()
+                ]
+            )
+        )
 
     # direct, relation_type=None is unspecified, relation_type
     if relation_type is None:
-        stmt = stmt.format('')
+        stmt = stmt.format("")
     # all("*" wildcard) relation_type
-    elif relation_type == '*':
-        stmt = stmt.format('[*]')
+    elif relation_type == "*":
+        stmt = stmt.format("[*]")
     else:
         # explicit relation_type
-        stmt = stmt.format('[{0}:`{1}`{2}]'.format(ident if ident else '', relation_type, rel_props))
+        stmt = stmt.format(
+            "[{0}:`{1}`{2}]".format(ident if ident else "", relation_type, rel_props)
+        )
 
     return "({0}){1}({2})".format(lhs, stmt, rhs)
 
 
-def _rel_merge_helper(lhs, rhs, ident='neomodelident', relation_type=None, direction=None, relation_properties=None, **kwargs):
+def _rel_merge_helper(
+    lhs,
+    rhs,
+    ident="neomodelident",
+    relation_type=None,
+    direction=None,
+    relation_properties=None,
+    **kwargs,
+):
     """
     Generate a relationship merging string, with specified parameters.
     Examples:
@@ -83,78 +109,90 @@ def _rel_merge_helper(lhs, rhs, ident='neomodelident', relation_type=None, direc
     """
 
     if direction == OUTGOING:
-        stmt = '-{0}->'
+        stmt = "-{0}->"
     elif direction == INCOMING:
-        stmt = '<-{0}-'
+        stmt = "<-{0}-"
     else:
-        stmt = '-{0}-'
+        stmt = "-{0}-"
 
-    rel_props = ''
-    rel_none_props = ''
+    rel_props = ""
+    rel_none_props = ""
 
     if relation_properties:
-        rel_props = ' {{{0}}}'.format(', '.join(
-            ['{0}: {1}'.format(key, value) for key, value in relation_properties.items() if value is not None]))
+        rel_props = " {{{0}}}".format(
+            ", ".join(
+                [
+                    "{0}: {1}".format(key, value)
+                    for key, value in relation_properties.items()
+                    if value is not None
+                ]
+            )
+        )
         if None in relation_properties.values():
-            rel_none_props = ' ON CREATE SET {0} ON MATCH SET {0}'.format(
-                ', '.join(
-                    ['{0}.{1}={2}'.format(ident, key, '${!s}'.format(key)) for key, value in relation_properties.items() if value is None])
+            rel_none_props = " ON CREATE SET {0} ON MATCH SET {0}".format(
+                ", ".join(
+                    [
+                        "{0}.{1}={2}".format(ident, key, "${!s}".format(key))
+                        for key, value in relation_properties.items()
+                        if value is None
+                    ]
+                )
             )
     # direct, relation_type=None is unspecified, relation_type
     if relation_type is None:
-        stmt = stmt.format('')
+        stmt = stmt.format("")
     # all("*" wildcard) relation_type
-    elif relation_type == '*':
-        stmt = stmt.format('[*]')
+    elif relation_type == "*":
+        stmt = stmt.format("[*]")
     else:
         # explicit relation_type
-        stmt = stmt.format('[{0}:`{1}`{2}]'.format(ident, relation_type, rel_props))
+        stmt = stmt.format("[{0}:`{1}`{2}]".format(ident, relation_type, rel_props))
 
     return "({0}){1}({2}){3}".format(lhs, stmt, rhs, rel_none_props)
 
 
 # special operators
-_SPECIAL_OPERATOR_IN = 'IN'
-_SPECIAL_OPERATOR_INSENSITIVE = '(?i)'
-_SPECIAL_OPERATOR_ISNULL = 'IS NULL'
-_SPECIAL_OPERATOR_ISNOTNULL = 'IS NOT NULL'
-_SPECIAL_OPERATOR_REGEX = '=~'
+_SPECIAL_OPERATOR_IN = "IN"
+_SPECIAL_OPERATOR_INSENSITIVE = "(?i)"
+_SPECIAL_OPERATOR_ISNULL = "IS NULL"
+_SPECIAL_OPERATOR_ISNOTNULL = "IS NOT NULL"
+_SPECIAL_OPERATOR_REGEX = "=~"
 
 _UNARY_OPERATORS = (_SPECIAL_OPERATOR_ISNULL, _SPECIAL_OPERATOR_ISNOTNULL)
 
-_REGEX_INSESITIVE = _SPECIAL_OPERATOR_INSENSITIVE + '{}'
-_REGEX_CONTAINS = '.*{}.*'
-_REGEX_STARTSWITH = '{}.*'
-_REGEX_ENDSWITH = '.*{}'
+_REGEX_INSESITIVE = _SPECIAL_OPERATOR_INSENSITIVE + "{}"
+_REGEX_CONTAINS = ".*{}.*"
+_REGEX_STARTSWITH = "{}.*"
+_REGEX_ENDSWITH = ".*{}"
 
 # regex operations that require escaping
 _STRING_REGEX_OPERATOR_TABLE = {
-    'iexact': _REGEX_INSESITIVE,
-    'contains': _REGEX_CONTAINS,
-    'icontains': _SPECIAL_OPERATOR_INSENSITIVE + _REGEX_CONTAINS,
-    'startswith': _REGEX_STARTSWITH,
-    'istartswith': _SPECIAL_OPERATOR_INSENSITIVE + _REGEX_STARTSWITH,
-    'endswith': _REGEX_ENDSWITH,
-    'iendswith': _SPECIAL_OPERATOR_INSENSITIVE + _REGEX_ENDSWITH,
+    "iexact": _REGEX_INSESITIVE,
+    "contains": _REGEX_CONTAINS,
+    "icontains": _SPECIAL_OPERATOR_INSENSITIVE + _REGEX_CONTAINS,
+    "startswith": _REGEX_STARTSWITH,
+    "istartswith": _SPECIAL_OPERATOR_INSENSITIVE + _REGEX_STARTSWITH,
+    "endswith": _REGEX_ENDSWITH,
+    "iendswith": _SPECIAL_OPERATOR_INSENSITIVE + _REGEX_ENDSWITH,
 }
 # regex operations that do not require escaping
 _REGEX_OPERATOR_TABLE = {
-    'iregex': _REGEX_INSESITIVE,
+    "iregex": _REGEX_INSESITIVE,
 }
 # list all regex operations, these will require formatting of the value
 _REGEX_OPERATOR_TABLE.update(_STRING_REGEX_OPERATOR_TABLE)
 
 # list all supported operators
 OPERATOR_TABLE = {
-    'lt': '<',
-    'gt': '>',
-    'lte': '<=',
-    'gte': '>=',
-    'ne': '<>',
-    'in': _SPECIAL_OPERATOR_IN,
-    'isnull': _SPECIAL_OPERATOR_ISNULL,
-    'regex': _SPECIAL_OPERATOR_REGEX,
-    'exact': '='
+    "lt": "<",
+    "gt": ">",
+    "lte": "<=",
+    "gte": ">=",
+    "ne": "<>",
+    "in": _SPECIAL_OPERATOR_IN,
+    "isnull": _SPECIAL_OPERATOR_ISNULL,
+    "regex": _SPECIAL_OPERATOR_REGEX,
+    "exact": "=",
 }
 # add all regex operators
 OPERATOR_TABLE.update(_REGEX_OPERATOR_TABLE)
@@ -167,9 +205,11 @@ def install_traversals(cls, node_set):
     """
     rels = cls.defined_properties(rels=True, aliases=False, properties=False)
 
-    for key, value in rels.items():
+    for key in rels.keys():
         if hasattr(node_set, key):
-            raise ValueError("Can't install traversal '{0}' exists on NodeSet".format(key))
+            raise ValueError(
+                "Can't install traversal '{0}' exists on NodeSet".format(key)
+            )
 
         rel = getattr(cls, key)
         rel._lookup_node_class()
@@ -187,12 +227,12 @@ def process_filter_args(cls, kwargs):
     output = {}
 
     for key, value in kwargs.items():
-        if '__' in key:
-            prop, operator = key.rsplit('__')
+        if "__" in key:
+            prop, operator = key.rsplit("__")
             operator = OPERATOR_TABLE[operator]
         else:
             prop = key
-            operator = '='
+            operator = "="
 
         if prop not in cls.defined_properties(rels=False):
             raise ValueError("No such property {0} on {1}".format(prop, cls.__name__))
@@ -205,17 +245,23 @@ def process_filter_args(cls, kwargs):
             # handle special operators
             if operator == _SPECIAL_OPERATOR_IN:
                 if not isinstance(value, tuple) and not isinstance(value, list):
-                    raise ValueError('Value must be a tuple or list for IN operation {0}={1}'.format(key, value))
+                    raise ValueError(
+                        "Value must be a tuple or list for IN operation {0}={1}".format(
+                            key, value
+                        )
+                    )
                 deflated_value = [property_obj.deflate(v) for v in value]
             elif operator == _SPECIAL_OPERATOR_ISNULL:
                 if not isinstance(value, bool):
-                    raise ValueError('Value must be a bool for isnull operation on {0}'.format(key))
-                operator = 'IS NULL' if value else 'IS NOT NULL'
+                    raise ValueError(
+                        "Value must be a bool for isnull operation on {0}".format(key)
+                    )
+                operator = "IS NULL" if value else "IS NOT NULL"
                 deflated_value = None
             elif operator in _REGEX_OPERATOR_TABLE.values():
                 deflated_value = property_obj.deflate(value)
                 if not isinstance(deflated_value, basestring):
-                    raise ValueError('Must be a string value for {0}'.format(key))
+                    raise ValueError("Must be a string value for {0}".format(key))
                 if operator in _STRING_REGEX_OPERATOR_TABLE.values():
                     deflated_value = re.escape(deflated_value)
                 deflated_value = operator.format(deflated_value)
@@ -241,7 +287,9 @@ def process_has_args(cls, kwargs):
 
     for key, value in kwargs.items():
         if key not in rel_definitions:
-            raise ValueError("No such relation {0} defined on a {1}".format(key, cls.__name__))
+            raise ValueError(
+                "No such relation {0} defined on a {1}".format(key, cls.__name__)
+            )
 
         rhs_ident = key
 
@@ -259,10 +307,10 @@ def process_has_args(cls, kwargs):
     return match, dont_match
 
 
-class QueryBuilder(object):
+class QueryBuilder:
     def __init__(self, node_set):
         self.node_set = node_set
-        self._ast = {'match': [], 'where': []}
+        self._ast = {"match": [], "where": []}
         self._query_params = {}
         self._place_holder_registry = {}
         self._ident_count = 0
@@ -270,64 +318,76 @@ class QueryBuilder(object):
     def build_ast(self):
         self.build_source(self.node_set)
 
-        if hasattr(self.node_set, 'skip'):
-            self._ast['skip'] = self.node_set.skip
-        if hasattr(self.node_set, 'limit'):
-            self._ast['limit'] = self.node_set.limit
+        if hasattr(self.node_set, "skip"):
+            self._ast["skip"] = self.node_set.skip
+        if hasattr(self.node_set, "limit"):
+            self._ast["limit"] = self.node_set.limit
 
         return self
 
     def build_source(self, source):
         if isinstance(source, Traversal):
             return self.build_traversal(source)
-        elif isinstance(source, NodeSet):
-            if inspect.isclass(source.source) and issubclass(source.source, StructuredNode):
+        if isinstance(source, NodeSet):
+            if inspect.isclass(source.source) and issubclass(
+                source.source, StructuredNode
+            ):
                 ident = self.build_label(source.source.__label__.lower(), source.source)
             else:
                 ident = self.build_source(source.source)
 
             self.build_additional_match(ident, source)
 
-            if hasattr(source, '_order_by'):
+            if hasattr(source, "_order_by"):
                 self.build_order_by(ident, source)
 
             if source.filters or source.q_filters:
-                self.build_where_stmt(ident, source.filters, source.q_filters, source_class=source.source_class)
+                self.build_where_stmt(
+                    ident,
+                    source.filters,
+                    source.q_filters,
+                    source_class=source.source_class,
+                )
 
             return ident
-        elif isinstance(source, StructuredNode):
+        if isinstance(source, StructuredNode):
             return self.build_node(source)
-        else:
-            raise ValueError("Unknown source type " + repr(source))
+        raise ValueError("Unknown source type " + repr(source))
 
     def create_ident(self):
         self._ident_count += 1
-        return 'r' + str(self._ident_count)
+        return "r" + str(self._ident_count)
 
     def build_order_by(self, ident, source):
-        if '?' in source._order_by:
-            self._ast['with'] = '{0}, rand() as r'.format(ident)
-            self._ast['order_by'] = 'r'
+        if "?" in source._order_by:
+            self._ast["with"] = "{0}, rand() as r".format(ident)
+            self._ast["order_by"] = "r"
         else:
-            self._ast['order_by'] = ['{0}.{1}'.format(ident, p)
-                                     for p in source._order_by]
+            self._ast["order_by"] = [
+                "{0}.{1}".format(ident, p) for p in source._order_by
+            ]
 
     def build_traversal(self, traversal):
         """
         traverse a relationship from a node to a set of nodes
         """
         # build source
-        rhs_label = ':' + traversal.target_class.__label__
+        rhs_label = ":" + traversal.target_class.__label__
 
         # build source
         lhs_ident = self.build_source(traversal.source)
         rhs_ident = traversal.name + rhs_label
-        self._ast['return'] = traversal.name
-        self._ast['result_class'] = traversal.target_class
+        self._ast["return"] = traversal.name
+        self._ast["result_class"] = traversal.target_class
 
         rel_ident = self.create_ident()
-        stmt = _rel_helper(lhs=lhs_ident, rhs=rhs_ident, ident=rel_ident, **traversal.definition)
-        self._ast['match'].append(stmt)
+        stmt = _rel_helper(
+            lhs=lhs_ident,
+            rhs=rhs_ident,
+            ident=rel_ident,
+            **traversal.definition,
+        )
+        self._ast["match"].append(stmt)
 
         if traversal.filters:
             self.build_where_stmt(rel_ident, traversal.filters)
@@ -339,44 +399,46 @@ class QueryBuilder(object):
         place_holder = self._register_place_holder(ident)
 
         # Hack to emulate START to lookup a node by id
-        _node_lookup = 'MATCH ({0}) WHERE id({1})=${2} WITH {3}'.format(ident, ident, place_holder, ident)
-        self._ast['lookup'] = _node_lookup
+        _node_lookup = "MATCH ({0}) WHERE id({0})=${1} WITH {0}".format(
+            ident, place_holder
+        )
+        self._ast["lookup"] = _node_lookup
 
         self._query_params[place_holder] = node.id
 
-        self._ast['return'] = ident
-        self._ast['result_class'] = node.__class__
+        self._ast["return"] = ident
+        self._ast["result_class"] = node.__class__
         return ident
 
     def build_label(self, ident, cls):
         """
         match nodes by a label
         """
-        ident_w_label = ident + ':' + cls.__label__
-        self._ast['match'].append('({0})'.format(ident_w_label))
-        self._ast['return'] = ident
-        self._ast['result_class'] = cls
+        ident_w_label = ident + ":" + cls.__label__
+        self._ast["match"].append("({0})".format(ident_w_label))
+        self._ast["return"] = ident
+        self._ast["result_class"] = cls
         return ident
 
     def build_additional_match(self, ident, node_set):
         """
-            handle additional matches supplied by 'has()' calls
+        handle additional matches supplied by 'has()' calls
         """
         source_ident = ident
 
-        for key, value in node_set.must_match.items():
+        for _, value in node_set.must_match.items():
             if isinstance(value, dict):
-                label = ':' + value['node_class'].__label__
-                stmt = _rel_helper(lhs=source_ident, rhs=label, ident='', **value)
-                self._ast['where'].append(stmt)
+                label = ":" + value["node_class"].__label__
+                stmt = _rel_helper(lhs=source_ident, rhs=label, ident="", **value)
+                self._ast["where"].append(stmt)
             else:
                 raise ValueError("Expecting dict got: " + repr(value))
 
-        for key, val in node_set.dont_match.items():
+        for _, val in node_set.dont_match.items():
             if isinstance(val, dict):
-                label = ':' + val['node_class'].__label__
-                stmt = _rel_helper(lhs=source_ident, rhs=label, ident='', **val)
-                self._ast['where'].append('NOT ' + stmt)
+                label = ":" + val["node_class"].__label__
+                stmt = _rel_helper(lhs=source_ident, rhs=label, ident="", **val)
+                self._ast["where"].append("NOT " + stmt)
             else:
                 raise ValueError("Expecting dict got: " + repr(val))
 
@@ -385,7 +447,7 @@ class QueryBuilder(object):
             self._place_holder_registry[key] += 1
         else:
             self._place_holder_registry[key] = 1
-        return key + '_' + str(self._place_holder_registry[key])
+        return key + "_" + str(self._place_holder_registry[key])
 
     def _parse_q_filters(self, ident, q, source_class):
         target = []
@@ -399,18 +461,20 @@ class QueryBuilder(object):
                 kwargs = {child[0]: child[1]}
                 filters = process_filter_args(source_class, kwargs)
                 for prop, op_and_val in filters.items():
-                    op, val = op_and_val
-                    if op in _UNARY_OPERATORS:
+                    operator, val = op_and_val
+                    if operator in _UNARY_OPERATORS:
                         # unary operators do not have a parameter
-                        statement = '{0}.{1} {2}'.format(ident, prop, op)
+                        statement = "{0}.{1} {2}".format(ident, prop, operator)
                     else:
-                        place_holder = self._register_place_holder(ident + '_' + prop)
-                        statement = '{0}.{1} {2} ${3}'.format(ident, prop, op, place_holder)
+                        place_holder = self._register_place_holder(ident + "_" + prop)
+                        statement = "{0}.{1} {2} ${3}".format(
+                            ident, prop, operator, place_holder
+                        )
                         self._query_params[place_holder] = val
                     target.append(statement)
-        ret = ' {0} '.format(q.connector).join(target)
+        ret = " {0} ".format(q.connector).join(target)
         if q.negated:
-            ret = 'NOT ({0})'.format(ret)
+            ret = "NOT ({0})".format(ret)
         return ret
 
     def build_where_stmt(self, ident, filters, q_filters=None, source_class=None):
@@ -420,98 +484,107 @@ class QueryBuilder(object):
         if q_filters is not None:
             stmts = self._parse_q_filters(ident, q_filters, source_class)
             if stmts:
-                self._ast['where'].append(stmts)
+                self._ast["where"].append(stmts)
         else:
             stmts = []
             for row in filters:
                 negate = False
 
                 # pre-process NOT cases as they are nested dicts
-                if '__NOT__' in row and len(row) == 1:
+                if "__NOT__" in row and len(row) == 1:
                     negate = True
-                    row = row['__NOT__']
+                    row = row["__NOT__"]
 
-                for prop, op_and_val in row.items():
-                    op, val = op_and_val
-                    if op in _UNARY_OPERATORS:
+                for prop, operator_and_val in row.items():
+                    operator, val = operator_and_val
+                    if operator in _UNARY_OPERATORS:
                         # unary operators do not have a parameter
-                        statement = '{0} {1}.{2} {3}'.format('NOT' if negate else '', ident, prop, op)
+                        statement = "{0} {1}.{2} {3}".format(
+                            "NOT" if negate else "", ident, prop, operator
+                        )
                     else:
-                        place_holder = self._register_place_holder(ident + '_' + prop)
-                        statement = '{0} {1}.{2} {3} ${4}'.format('NOT' if negate else '', ident, prop, op, place_holder)
+                        place_holder = self._register_place_holder(ident + "_" + prop)
+                        statement = "{0} {1}.{2} {3} ${4}".format(
+                            "NOT" if negate else "",
+                            ident,
+                            prop,
+                            operator,
+                            place_holder,
+                        )
                         self._query_params[place_holder] = val
                     stmts.append(statement)
 
-            self._ast['where'].append(' AND '.join(stmts))
+            self._ast["where"].append(" AND ".join(stmts))
 
     def build_query(self):
-        query = ''
+        query = ""
 
-        if 'lookup' in self._ast:
-            query += self._ast['lookup']
+        if "lookup" in self._ast:
+            query += self._ast["lookup"]
 
-        query += ' MATCH '
-        query += ', '.join(['({0})'.format(i) for i in self._ast['match']])
+        query += " MATCH "
+        query += ", ".join(["({0})".format(i) for i in self._ast["match"]])
 
-        if 'where' in self._ast and self._ast['where']:
-            query += ' WHERE '
-            query += ' AND '.join(self._ast['where'])
+        if "where" in self._ast and self._ast["where"]:
+            query += " WHERE "
+            query += " AND ".join(self._ast["where"])
 
-        if 'with' in self._ast and self._ast['with']:
-            query += ' WITH '
-            query += self._ast['with']
+        if "with" in self._ast and self._ast["with"]:
+            query += " WITH "
+            query += self._ast["with"]
 
-        query += ' RETURN ' + self._ast['return']
+        query += " RETURN " + self._ast["return"]
 
-        if 'order_by' in self._ast and self._ast['order_by']:
-            query += ' ORDER BY '
-            query += ', '.join(self._ast['order_by'])
+        if "order_by" in self._ast and self._ast["order_by"]:
+            query += " ORDER BY "
+            query += ", ".join(self._ast["order_by"])
 
-        if 'skip' in self._ast:
-            query += ' SKIP {0:d}'.format(self._ast['skip'])
+        if "skip" in self._ast:
+            query += " SKIP {0:d}".format(self._ast["skip"])
 
-        if 'limit' in self._ast:
-            query += ' LIMIT {0:d}'.format(self._ast['limit'])
+        if "limit" in self._ast:
+            query += " LIMIT {0:d}".format(self._ast["limit"])
 
         return query
 
     def _count(self):
-        self._ast['return'] = 'count({0})'.format(self._ast['return'])
+        self._ast["return"] = "count({0})".format(self._ast["return"])
         # drop order_by, results in an invalid query
-        self._ast.pop('order_by', None)
+        self._ast.pop("order_by", None)
         query = self.build_query()
         results, _ = db.cypher_query(query, self._query_params)
         return int(results[0][0])
 
     def _contains(self, node_id):
         # inject id = into ast
-        ident = self._ast['return']
-        place_holder = self._register_place_holder(ident + '_contains')
-        self._ast['where'].append('id({0}) = ${1}'.format(ident, place_holder))
+        ident = self._ast["return"]
+        place_holder = self._register_place_holder(ident + "_contains")
+        self._ast["where"].append("id({0}) = ${1}".format(ident, place_holder))
         self._query_params[place_holder] = node_id
         return self._count() >= 1
 
     def _execute(self, lazy=False):
         if lazy:
             # inject id = into ast
-            self._ast['return'] = 'id({})'.format(self._ast['return'])
+            self._ast["return"] = "id({})".format(self._ast["return"])
         query = self.build_query()
-        results, _ = db.cypher_query(query, self._query_params, resolve_objects=True)            
-        # The following is not as elegant as it could be but had to be copied from the 
+        results, _ = db.cypher_query(query, self._query_params, resolve_objects=True)
+        # The following is not as elegant as it could be but had to be copied from the
         # version prior to cypher_query with the resolve_objects capability.
-        # It seems that certain calls are only supposed to be focusing to the first 
+        # It seems that certain calls are only supposed to be focusing to the first
         # result item returned (?)
         if results:
             return [n[0] for n in results]
         return []
-        
-        
-class BaseSet(object):
+
+
+class BaseSet:
     """
     Base class for all node sets.
 
     Contains common python magic methods, __len__, __contains__ etc
     """
+
     query_cls = QueryBuilder
 
     def all(self, lazy=False):
@@ -537,11 +610,11 @@ class BaseSet(object):
 
     def __contains__(self, obj):
         if isinstance(obj, StructuredNode):
-            if hasattr(obj, 'id'):
+            if hasattr(obj, "id"):
                 return self.query_cls(self).build_ast()._contains(int(obj.id))
             raise ValueError("Unsaved node: " + repr(obj))
-        else:
-            raise ValueError("Expecting StructuredNode instance")
+
+        raise ValueError("Expecting StructuredNode instance")
 
     def __getitem__(self, key):
         if isinstance(key, slice):
@@ -553,19 +626,22 @@ class BaseSet(object):
             elif key.start:
                 self.skip = key.start
 
-            return self.query_cls(self).build_ast()._execute()
+            return self
 
-        elif isinstance(key, int):
+        if isinstance(key, int):
             self.skip = key
             self.limit = 1
 
             return self.query_cls(self).build_ast()._execute()[0]
 
+        return None
+
 
 class NodeSet(BaseSet):
     """
     A class representing as set of nodes matching common query parameters
     """
+
     def __init__(self, source):
         self.source = source  # could be a Traverse object or a node class
         if isinstance(source, Traversal):
@@ -603,10 +679,9 @@ class NodeSet(BaseSet):
         result = self._get(limit=2, lazy=lazy, **kwargs)
         if len(result) > 1:
             raise MultipleNodesReturned(repr(kwargs))
-        elif not result:
+        if not result:
             raise self.source_class.DoesNotExist(repr(kwargs))
-        else:
-            return result[0]
+        return result[0]
 
     def get_or_none(self, **kwargs):
         """
@@ -618,7 +693,7 @@ class NodeSet(BaseSet):
         try:
             return self.get(**kwargs)
         except self.source_class.DoesNotExist:
-            pass
+            return None
 
     def first(self, **kwargs):
         """
@@ -644,6 +719,7 @@ class NodeSet(BaseSet):
             return self.first(**kwargs)
         except self.source_class.DoesNotExist:
             pass
+        return None
 
     def filter(self, *args, **kwargs):
         """
@@ -707,30 +783,33 @@ class NodeSet(BaseSet):
         remove ordering.
         """
         should_remove = len(props) == 1 and props[0] is None
-        if not hasattr(self, '_order_by') or should_remove:
+        if not hasattr(self, "_order_by") or should_remove:
             self._order_by = []
             if should_remove:
                 return self
-        if '?' in props:
-            self._order_by.append('?')
+        if "?" in props:
+            self._order_by.append("?")
         else:
             for prop in props:
                 prop = prop.strip()
-                if prop.startswith('-'):
+                if prop.startswith("-"):
                     prop = prop[1:]
                     desc = True
                 else:
                     desc = False
 
                 if prop not in self.source_class.defined_properties(rels=False):
-                    raise ValueError("No such property {0} on {1}".format(
-                        prop, self.source_class.__name__))
+                    raise ValueError(
+                        "No such property {0} on {1}".format(
+                            prop, self.source_class.__name__
+                        )
+                    )
 
                 property_obj = getattr(self.source_class, prop)
                 if isinstance(property_obj, AliasProperty):
                     prop = property_obj.aliased_to()
 
-                self._order_by.append(prop + (' DESC' if desc else ''))
+                self._order_by.append(prop + (" DESC" if desc else ""))
 
         return self
 
@@ -766,20 +845,23 @@ class Traversal(BaseSet):
         elif isinstance(source, NodeSet):
             self.source_class = source.source_class
         else:
-            raise TypeError("Bad source for traversal: "
-                            "{0}".format(type(source)))
+            raise TypeError("Bad source for traversal: " "{0}".format(type(source)))
 
-        invalid_keys = (
-                set(definition) - {'direction', 'model', 'node_class', 'relation_type'}
-        )
+        invalid_keys = set(definition) - {
+            "direction",
+            "model",
+            "node_class",
+            "relation_type",
+        }
         if invalid_keys:
             raise ValueError(
-                'Unallowed keys in Traversal definition: {invalid_keys}'
-                .format(invalid_keys=invalid_keys)
+                "Unallowed keys in Traversal definition: {invalid_keys}".format(
+                    invalid_keys=invalid_keys
+                )
             )
 
         self.definition = definition
-        self.target_class = definition['node_class']
+        self.target_class = definition["node_class"]
         self.name = name
         self.filters = []
 
@@ -793,9 +875,11 @@ class Traversal(BaseSet):
         :return: self
         """
         if kwargs:
-            if self.definition.get('model') is None:
-                raise ValueError("match() with filter only available on relationships with a model")
-            output = process_filter_args(self.definition['model'], kwargs)
+            if self.definition.get("model") is None:
+                raise ValueError(
+                    "match() with filter only available on relationships with a model"
+                )
+            output = process_filter_args(self.definition["model"], kwargs)
             if output:
                 self.filters.append(output)
         return self
