@@ -1,31 +1,29 @@
 import functools
 import json
+import re
 import sys
 import types
-import re
 import uuid
-import warnings
 from datetime import date, datetime
 
+import neo4j.time
 import pytz
 
-import neo4j.time
-
 from neomodel import config
-from neomodel.exceptions import InflateError, DeflateError, RequiredProperty
-
+from neomodel.exceptions import DeflateError, InflateError, RequiredProperty
 
 if sys.version_info >= (3, 0):
-    unicode = str
+    Unicode = str
 
 
 def display_for(key):
     def display_choice(self):
         return getattr(self.__class__, key).choices[getattr(self, key)]
+
     return display_choice
 
 
-class PropertyManager(object):
+class PropertyManager:
     """
     Common methods for handling properties on node and relationship objects.
     """
@@ -33,20 +31,22 @@ class PropertyManager(object):
     def __init__(self, **kwargs):
         properties = getattr(self, "__all_properties__", None)
         if properties is None:
-            properties = \
-                self.defined_properties(rels=False, aliases=False).items()
+            properties = self.defined_properties(rels=False, aliases=False).items()
         for name, property in properties:
             if kwargs.get(name) is None:
-                if getattr(property, 'has_default', False):
+                if getattr(property, "has_default", False):
                     setattr(self, name, property.default_value())
                 else:
                     setattr(self, name, None)
             else:
                 setattr(self, name, kwargs[name])
 
-            if getattr(property, 'choices', None):
-                setattr(self, 'get_{0}_display'.format(name),
-                        types.MethodType(display_for(name), self))
+            if getattr(property, "choices", None):
+                setattr(
+                    self,
+                    "get_{0}_display".format(name),
+                    types.MethodType(display_for(name), self),
+                )
 
             if name in kwargs:
                 del kwargs[name]
@@ -54,7 +54,8 @@ class PropertyManager(object):
         aliases = getattr(self, "__all_aliases__", None)
         if aliases is None:
             aliases = self.defined_properties(
-                aliases=True, rels=False, properties=False).items()
+                aliases=True, rels=False, properties=False
+            ).items()
         for name, property in aliases:
             if name in kwargs:
                 setattr(self, name, kwargs[name])
@@ -68,26 +69,30 @@ class PropertyManager(object):
     def __properties__(self):
         from .relationship_manager import RelationshipManager
 
-        return dict((name, value) for name, value in vars(self).items()
-                    if not name.startswith('_')
-                    and not callable(value)
-                    and not isinstance(value,
-                                       (RelationshipManager, AliasProperty,))
-                    )
+        return dict(
+            (name, value)
+            for name, value in vars(self).items()
+            if not name.startswith("_")
+            and not callable(value)
+            and not isinstance(
+                value,
+                (
+                    RelationshipManager,
+                    AliasProperty,
+                ),
+            )
+        )
 
     @classmethod
     def deflate(cls, properties, obj=None, skip_empty=False):
         # deflate dict ready to be stored
         deflated = {}
-        for name, property \
-                in cls.defined_properties(aliases=False, rels=False).items():
+        for name, property in cls.defined_properties(aliases=False, rels=False).items():
             db_property = property.db_property or name
             if properties.get(name) is not None:
                 deflated[db_property] = property.deflate(properties[name], obj)
             elif property.has_default:
-                deflated[db_property] = property.deflate(
-                    property.default_value(), obj
-                )
+                deflated[db_property] = property.deflate(property.default_value(), obj)
             elif property.required:
                 raise RequiredProperty(name, cls)
             elif not skip_empty:
@@ -97,26 +102,33 @@ class PropertyManager(object):
     @classmethod
     def defined_properties(cls, aliases=True, properties=True, rels=True):
         from .relationship_manager import RelationshipDefinition
+
         props = {}
         for baseclass in reversed(cls.__mro__):
-            props.update(dict(
-                (name, property) for name, property in vars(baseclass).items()
-                if (aliases and isinstance(property, AliasProperty))
-                or (properties and isinstance(property, Property)
-                    and not isinstance(property, AliasProperty))
-                or (rels and isinstance(property, RelationshipDefinition))
-            ))
+            props.update(
+                dict(
+                    (name, property)
+                    for name, property in vars(baseclass).items()
+                    if (aliases and isinstance(property, AliasProperty))
+                    or (
+                        properties
+                        and isinstance(property, Property)
+                        and not isinstance(property, AliasProperty)
+                    )
+                    or (rels and isinstance(property, RelationshipDefinition))
+                )
+            )
         return props
 
 
 def validator(fn):
-    fn_name = fn.func_name if hasattr(fn, 'func_name') else fn.__name__
-    if fn_name == 'inflate':
+    fn_name = fn.func_name if hasattr(fn, "func_name") else fn.__name__
+    if fn_name == "inflate":
         exc_class = InflateError
-    elif fn_name == 'deflate':
+    elif fn_name == "deflate":
         exc_class = DeflateError
     else:
-        raise Exception("Unknown Property method " + fn_name)
+        raise ValueError("Unknown Property method " + fn_name)
 
     @functools.wraps(fn)
     def _validator(self, value, obj=None, rethrow=True):
@@ -124,7 +136,7 @@ def validator(fn):
             try:
                 return fn(self, value)
             except Exception as e:
-                raise exc_class(self.name, self.owner, str(e), obj)
+                raise exc_class(self.name, self.owner, str(e), obj) from e
         else:
             # For using with ArrayProperty where we don't want an Inflate/Deflate error.
             return fn(self, value)
@@ -132,7 +144,7 @@ def validator(fn):
     return _validator
 
 
-class Property(object):
+class Property:
     """
     Base class for object properties.
 
@@ -154,11 +166,20 @@ class Property(object):
     :type help_text: :class:`str`
     """
 
-    form_field_class = 'CharField'
-
-    def __init__(self, unique_index=False, index=False, required=False, default=None,
-                 db_property=None, label=None, help_text=None, **kwargs):
+    form_field_class = "CharField"
 
+    # pylint:disable=unused-argument
+    def __init__(
+        self,
+        unique_index=False,
+        index=False,
+        required=False,
+        default=None,
+        db_property=None,
+        label=None,
+        help_text=None,
+        **kwargs,
+    ):
         if default is not None and required:
             raise ValueError(
                 "The arguments `required` and `default` are mutually exclusive."
@@ -172,7 +193,7 @@ class Property(object):
         self.unique_index = unique_index
         self.index = index
         self.default = default
-        self.has_default = True if self.default is not None else False
+        self.has_default = self.default is not None
         self.db_property = db_property
         self.label = label
         self.help_text = help_text
@@ -184,12 +205,10 @@ class Property(object):
         :return: the value
         """
         if self.has_default:
-            if hasattr(self.default, '__call__'):
+            if hasattr(self.default, "__call__"):
                 return self.default()
-            else:
-                return self.default
-        else:
-            raise Exception("No default value specified")
+            return self.default
+        raise ValueError("No default value specified")
 
     @property
     def is_indexed(self):
@@ -211,44 +230,23 @@ class NormalizedProperty(Property):
         return self.normalize(value)
 
     def default_value(self):
-        default = super(NormalizedProperty, self).default_value()
+        default = super().default_value()
         return self.normalize(default)
 
     def normalize(self, value):
-        raise NotImplementedError('Specialize normalize method')
-
-
-# TODO remove this with the next major release
-def _warn_NormalProperty_renamed():
-    warnings.warn(
-        'The class NormalProperty was renamed to NormalizedProperty. '
-        'Use that one as base class. The former will be removed in the next '
-        'major release.', DeprecationWarning)
-
-
-if sys.version_info >= (3, 6):
-    class NormalProperty(NormalizedProperty):
-
-        def __init_subclass__(cls, **kwargs):
-            _warn_NormalProperty_renamed()
-else:
-    class NormalProperty(NormalizedProperty):
-
-        def __init__(self, *args, **kwargs):
-            _warn_NormalProperty_renamed()
-            super(NormalProperty, self).__init__(*args, **kwargs)
-##
+        raise NotImplementedError("Specialize normalize method")
 
 
 class RegexProperty(NormalizedProperty):
-    """
+    r"""
     Validates a property against a regular expression.
 
     If sub-classing set:
 
         expression = r'[^@]+@[^@]+\.[^@]+'
     """
-    form_field_class = 'RegexField'
+
+    form_field_class = "RegexField"
 
     expression = None
 
@@ -258,17 +256,17 @@ class RegexProperty(NormalizedProperty):
 
         :param str expression: regular expression validating this property
         """
-        super(RegexProperty, self).__init__(**kwargs)
+        super().__init__(**kwargs)
         actual_re = expression or self.expression
         if actual_re is None:
-            raise ValueError('expression is undefined')
+            raise ValueError("expression is undefined")
         self.expression = actual_re
 
     def normalize(self, value):
-        normal = unicode(value)
+        normal = Unicode(value)
         if not re.match(self.expression, normal):
             raise ValueError(
-                '{0!r} does not matches {1!r}'.format(
+                "{0!r} does not matches {1!r}".format(
                     value,
                     self.expression,
                 )
@@ -280,8 +278,9 @@ class EmailProperty(RegexProperty):
     """
     Store email addresses
     """
-    form_field_class = 'EmailField'
-    expression = r'[^@]+@[^@]+\.[^@]+'
+
+    form_field_class = "EmailField"
+    expression = r"[^@]+@[^@]+\.[^@]+"
 
 
 class StringProperty(NormalizedProperty):
@@ -299,11 +298,13 @@ class StringProperty(NormalizedProperty):
     def __init__(self, choices=None, max_length=None, **kwargs):
         if max_length is not None:
             if choices is not None:
-                raise ValueError("The arguments `choices` and `max_length` are mutually exclusive.")
-            if max_length<1:
+                raise ValueError(
+                    "The arguments `choices` and `max_length` are mutually exclusive."
+                )
+            if max_length < 1:
                 raise ValueError("`max_length` cannot be zero or take negative values.")
 
-        super(StringProperty, self).__init__(**kwargs)
+        super().__init__(**kwargs)
 
         self.max_length = max_length
         if choices is None:
@@ -311,36 +312,38 @@ class StringProperty(NormalizedProperty):
         else:
             try:
                 self.choices = dict(choices)
-            except Exception:
-                raise ValueError("The choices argument must be convertable to a dictionary.")
-            # Python 3:
-            except Exception as e:
-                raise ValueError("The choices argument must be convertable to "
-                                 "a dictionary.") from e
-            self.form_field_class = 'TypedChoiceField'
+            except Exception as exc:
+                raise ValueError(
+                    "The choices argument must be convertible to a dictionary."
+                ) from exc
+            self.form_field_class = "TypedChoiceField"
 
     def normalize(self, value):
         # One thing to note here is that the following two checks can remain uncoupled
         # as long as it is guaranteed (by the constructor) that `choices` and `max_length`
-        # are mutually exclusive. If that check in the constructor ever has to be removed, 
-        # these two validation checks here will have to be coupled so that having set 
+        # are mutually exclusive. If that check in the constructor ever has to be removed,
+        # these two validation checks here will have to be coupled so that having set
         # `choices` overrides having set the `max_length`.
         if self.choices is not None and value not in self.choices:
             raise ValueError("Invalid choice: {}".format(value))
         if self.max_length is not None and len(value) > self.max_length:
-            raise ValueError("Property max length exceeded. Expected {}, got {} == len('{}')".format(
-                             self.max_length, len(value), value))
-        return unicode(value)
+            raise ValueError(
+                "Property max length exceeded. Expected {}, got {} == len('{}')".format(
+                    self.max_length, len(value), value
+                )
+            )
+        return Unicode(value)
 
     def default_value(self):
-        return self.normalize(super(StringProperty, self).default_value())
+        return self.normalize(super().default_value())
 
 
 class IntegerProperty(Property):
     """
     Stores an Integer value
     """
-    form_field_class = 'IntegerField'
+
+    form_field_class = "IntegerField"
 
     @validator
     def inflate(self, value):
@@ -351,7 +354,7 @@ class IntegerProperty(Property):
         return int(value)
 
     def default_value(self):
-        return int(super(IntegerProperty, self).default_value())
+        return int(super().default_value())
 
 
 class ArrayProperty(Property):
@@ -370,18 +373,27 @@ class ArrayProperty(Property):
         # list item type
         if base_property is not None:
             if not isinstance(base_property, Property):
-                raise TypeError('Expecting neomodel Property')
+                raise TypeError("Expecting neomodel Property")
 
             if isinstance(base_property, ArrayProperty):
-                raise TypeError('Cannot have nested ArrayProperty')
+                raise TypeError("Cannot have nested ArrayProperty")
 
-            for ilegal_attr in ['default', 'index', 'unique_index', 'required']:
+            for ilegal_attr in [
+                "default",
+                "index",
+                "unique_index",
+                "required",
+            ]:
                 if getattr(base_property, ilegal_attr, None):
-                    raise ValueError('ArrayProperty base_property cannot have "{0}" set'.format(ilegal_attr))
+                    raise ValueError(
+                        'ArrayProperty base_property cannot have "{0}" set'.format(
+                            ilegal_attr
+                        )
+                    )
 
         self.base_property = base_property
 
-        super(ArrayProperty, self).__init__(**kwargs)
+        super().__init__(**kwargs)
 
     @validator
     def inflate(self, value):
@@ -398,14 +410,15 @@ class ArrayProperty(Property):
         return list(value)
 
     def default_value(self):
-        return list(super(ArrayProperty, self).default_value())
+        return list(super().default_value())
 
 
 class FloatProperty(Property):
     """
     Store a floating point value
     """
-    form_field_class = 'FloatField'
+
+    form_field_class = "FloatField"
 
     @validator
     def inflate(self, value):
@@ -416,14 +429,15 @@ class FloatProperty(Property):
         return float(value)
 
     def default_value(self):
-        return float(super(FloatProperty, self).default_value())
+        return float(super().default_value())
 
 
 class BooleanProperty(Property):
     """
     Stores a boolean value
     """
-    form_field_class = 'BooleanField'
+
+    form_field_class = "BooleanField"
 
     @validator
     def inflate(self, value):
@@ -434,14 +448,15 @@ class BooleanProperty(Property):
         return bool(value)
 
     def default_value(self):
-        return bool(super(BooleanProperty, self).default_value())
+        return bool(super().default_value())
 
 
 class DateProperty(Property):
     """
     Stores a date
     """
-    form_field_class = 'DateField'
+
+    form_field_class = "DateField"
 
     @validator
     def inflate(self, value):
@@ -449,16 +464,17 @@ class DateProperty(Property):
             value = date(value.year, value.month, value.day)
         elif isinstance(value, str):
             if "T" in value:
-                value = value[:value.find('T')]
-        return datetime.strptime(unicode(value), "%Y-%m-%d").date()
+                value = value[: value.find("T")]
+        return datetime.strptime(Unicode(value), "%Y-%m-%d").date()
 
     @validator
     def deflate(self, value):
         if not isinstance(value, date):
-            msg = 'datetime.date object expected, got {0}'.format(repr(value))
+            msg = "datetime.date object expected, got {0}".format(repr(value))
             raise ValueError(msg)
         return value.isoformat()
 
+
 class DateTimeFormatProperty(Property):
     """
     Store a datetime by custome format
@@ -469,64 +485,69 @@ class DateTimeFormatProperty(Property):
     :type default_now:  :class:`bool`
     :type format:       :class:`str`
     """
-    form_field_class = 'DateTimeFormatField'
+
+    form_field_class = "DateTimeFormatField"
 
     def __init__(self, default_now=False, format="%Y-%m-%d", **kwargs):
         if default_now:
-            if 'default' in kwargs:
-                raise ValueError('too many defaults')
-            kwargs['default'] = lambda: datetime.now()
+            if "default" in kwargs:
+                raise ValueError("too many defaults")
+            kwargs["default"] = datetime.now()
 
         self.format = format
-        super(DateTimeFormatProperty, self).__init__(**kwargs)
+        super().__init__(**kwargs)
 
     @validator
     def inflate(self, value):
-        return datetime.strptime(unicode(value), self.format)
+        return datetime.strptime(Unicode(value), self.format)
 
     @validator
     def deflate(self, value):
         if not isinstance(value, datetime):
-            raise ValueError('datetime object expected, got {0}.'.format(type(value)))
+            raise ValueError("datetime object expected, got {0}.".format(type(value)))
         return datetime.strftime(value, self.format)
 
 
-
-
 class DateTimeProperty(Property):
-    """ A property representing a :class:`datetime.datetime` object as
-        unix epoch.
+    """A property representing a :class:`datetime.datetime` object as
+    unix epoch.
 
-        :param default_now: If ``True``, the creation time (UTC) will be used as default.
-                            Defaults to ``False``.
-        :type default_now: :class:`bool`
+    :param default_now: If ``True``, the creation time (UTC) will be used as default.
+                        Defaults to ``False``.
+    :type default_now: :class:`bool`
     """
-    form_field_class = 'DateTimeField'
+
+    form_field_class = "DateTimeField"
 
     def __init__(self, default_now=False, **kwargs):
         if default_now:
-            if 'default' in kwargs:
-                raise ValueError('too many defaults')
-            kwargs['default'] = lambda: datetime.utcnow().replace(tzinfo=pytz.utc)
+            if "default" in kwargs:
+                raise ValueError("too many defaults")
+            kwargs["default"] = lambda: datetime.utcnow().replace(tzinfo=pytz.utc)
 
-        super(DateTimeProperty, self).__init__(**kwargs)
+        super().__init__(**kwargs)
 
     @validator
     def inflate(self, value):
         try:
             epoch = float(value)
-        except ValueError:
-            raise ValueError("Float or integer expected, got {0} can't inflate to "
-                             "datetime.".format(type(value)))
-        except TypeError:
+        except ValueError as exc:
+            raise ValueError(
+                "Float or integer expected, got {0} can't inflate to "
+                "datetime.".format(type(value))
+            ) from exc
+        except TypeError as exc:
             raise TypeError(
-                "Float or integer expected. Can't inflate {0} to datetime.".format(type(value)))
+                "Float or integer expected. Can't inflate {0} to datetime.".format(
+                    type(value)
+                )
+            ) from exc
         return datetime.utcfromtimestamp(epoch).replace(tzinfo=pytz.utc)
 
     @validator
     def deflate(self, value):
         if not isinstance(value, datetime):
-            raise ValueError('datetime object expected, got {0}.'.format(type(value)))
+            raise ValueError("datetime object expected, got {0}.".format(type(value)))
         if value.tzinfo:
             value = value.astimezone(pytz.utc)
             epoch_date = datetime(1970, 1, 1, tzinfo=pytz.utc)
@@ -546,7 +567,7 @@ class JSONProperty(Property):
     """
 
     def __init__(self, *args, **kwargs):
-        super(JSONProperty, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
     @validator
     def inflate(self, value):
@@ -597,18 +618,20 @@ class UniqueIdProperty(Property):
     """
 
     def __init__(self, **kwargs):
-        for item in ['required', 'unique_index', 'index', 'default']:
+        for item in ["required", "unique_index", "index", "default"]:
             if item in kwargs:
-                raise ValueError('{0} argument ignored by {1}'.format(item, self.__class__.__name__))
+                raise ValueError(
+                    "{0} argument ignored by {1}".format(item, self.__class__.__name__)
+                )
 
-        kwargs['unique_index'] = True
-        kwargs['default'] = lambda: uuid.uuid4().hex
-        super(UniqueIdProperty, self).__init__(**kwargs)
+        kwargs["unique_index"] = True
+        kwargs["default"] = lambda: uuid.uuid4().hex
+        super().__init__(**kwargs)
 
     @validator
     def inflate(self, value):
-        return unicode(value)
+        return Unicode(value)
 
     @validator
     def deflate(self, value):
-        return unicode(value)
+        return Unicode(value)
